Description Usage Arguments Value Examples
View source: R/app_screening.R
This app was designed to maximize efficiency in high-throughput screening scenarios.
To work, before this function is called the working directory must have a file named
key.csv, with columns last (last name), first (first name), study.id
(for the internal ID used to track participants within your study),
consent (leave blank when file is built –
the app will use this field to track which participants have registered consent),
hyfe.id (the Hyfe uid), password (the Hyfe-provided passworded that participants
may use to log into the research app, if the study also involves remote phone monitoring),
and url, which is the url link to the web app unique for every hyfe.id.
1 |
demo |
If TRUE, the function will create |
A shiny app.
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.