Description Usage Arguments Value
View source: R/utils_pool_user_data.R
This is a background function that is rarely called by analysts directly.
It takes a hyfe object created by a call to process_hyfe_data() in which the
argument by_user was set to TRUE such that each user's data was proessed separately,
and pools all the user data together. It main application is for certain plotting functions.
1 | pool_user_data(ho_by_user, group_users = TRUE, verbose = TRUE)
|
ho_by_user |
A |
group_users |
If |
verbose |
Print status updates? |
A list with the three timetable slots you expect in a hyfe object in which all
users are pooled together: hours, days, and weeks. See the
vignette for details on these tables.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.